Learn R Programming

tergm (version 3.4.1)

coef.stergm: Extract Model Coefficients

Description

coef is a Method which extracts model coefficients from objects returned by the stergm function. coefficients is an alias for it.

Usage

# S3 method for stergm
coef(object, …)
# S3 method for stergm
coefficients(object, …)

Arguments

object

A stergm fit.

other arguments.

Value

Coefficients extracted from object in the form of a list with two elements: formation, a vector of formation coefficients and dissolution, a vector of dissolution coefficients.

See Also

stergm and ergm