Weighted sum of ages of extant ties
# binary: edgecov.ages(x, attrname=NULL)either a square matrix of covariates, one for
each possible edge in the network, the name of a network
attribute of covariates, or a network; if the latter, or if the
network attribute named by x is itself a network, optional
argument attrname provides the name of the quantitative edge
attribute to use for covariate values (in this case, missing
edges in x are assigned a covariate value of zero).
This term adds one statistic equaling sum, over all ties present in the network, of the amount of time elapsed since formation, multiplied by a dyadic covariate.
"Weights" can be negative.
Unlike edgecov.mean.age , this statistic is well-defined on
an empty network. However, if used as a target, it appears to
produce highly biased dissolution parameter estimates if the goal
is to get an intended average duration.
ergmTerm for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "edgecov.ages", "subsection")