Learn R Programming

tergm (version 3.3.1)

gof.stergm: Goodness-of-fit methods for STERGM CMLE and CMPLE fits

Description

For now, these are simple wrappers around gof.ergm, print.gofobject, summary.gofobject, and plot.gofobject, respectively, to run goodness-of-fit for formation and dissolution models separately. This may change in the future.

Usage

## S3 method for class 'stergm':
gof(object, ...)
## S3 method for class 'gof.stergm':
print(x, ...)
## S3 method for class 'gof.stergm':
summary(object, ...)
## S3 method for class 'gof.stergm':
plot(x, ..., main="Goodness-of-fit diagnostics")

Arguments

object, x
For gof.stergm, stergm conditional MLE (CMLE) or conditional MPLE (CMPLE) fit. For the others, a gof.stergm object returned by gof.stergm.
main
Gives the title of the goodness-of-fit plots, which will have "Formation:" and "Dissolution:" prepended to it.
...
Additional arguments passed through to the respective functions in the ergm package.

Value

  • For gof.stergm, an object of class gof.stergm, which is simply a list with two named elements: formation and dissolution, each of them a gofobject returned by gof.ergm.

    For the others, nothing.

See Also

stergm, ergm, simulate.stergm, print.gofobject, plot.gofobject, summary.gofobject, mcmc.diagnostics.ergm

Examples

Run this code
data(samplk)

# Fit a transition from Time 1 to Time 2
samplk12 <- stergm(list(samplk1, samplk2),
                   formation=~edges+mutual+transitiveties+cyclicalties,
                   dissolution=~edges+mutual+transitiveties+cyclicalties,
                   estimate="CMLE")

samplk12.gof <- gof(samplk12)

samplk12.gof

summary(samplk12.gof)

plot(samplk12.gof)

plot(samplk12.gof, plotlogodds=TRUE)

Run the code above in your browser using DataLab