Learn R Programming

tergm (version 3.3.1)

impute.network.list: Impute missing dyads in a series of networks

Description

This function takes a list of networks with missing dyads and returns a list of networks with missing dyads imputed according to a list of imputation directives.

Usage

impute.network.list(nwl, imputers = c(), nwl.prepend = list(), nwl.append = list())

Arguments

nwl
A list of network objects or a network.list object.
imputers
A character vector giving one or more methods to impute missing dyads. Currenly implemented methods are as follows: [object Object],[object Object],[object Object],[object Object],[object Object] If length(imputers)>1 the specifie
nwl.prepend
An optional list of networks to treat as preceding those in nwl. They will not be imputed or returned, but they can be useful for imputing dyads in the first network in nwl, when using "previous" imputer.
nwl.append
An optional list of networks to treat as following those in nwl. They will not be imputed or returned, but they can be useful for imputing dyads in the last network in nwl, when using "next" imputer.

Value

  • A list of networks with missing dyads imputed.

See Also

network, is.na