logLik method for stergm.Functions to return the log-likelihood associated with a
stergm CMLE fit, evaluating it if necessary.
See logLik.ergm documentation for details and caveats.
logLikNull method computes the null model
likelihood. See ergm::logLikNull().
# S3 method for stergm
logLik(
object,
add = FALSE,
force.reeval = FALSE,
eval.loglik = add || force.reeval,
control = control.logLik.stergm(),
...
)# S3 method for stergm
logLikNull(object, control = control.logLik.stergm(), ...)
Logical: If TRUE, instead of returning the log-likelihood, return
object with log-likelihood value set.
Logical: If TRUE, reestimate the log-likelihood even if
object already has an estiamte.
Logical: If TRUE, evaluate the log-likelihood if not set
on object.
A list of control parameters for algorithm tuning.
Constructed using control.logLik.ergm.
Other arguments to the likelihood functions.
For logLik.stergm, add=FALSE (the default), a
logLik object. If add=TRUE (the default), an
ergm object or a
stergm object with the log-likelihood set. For
logLikNull.stergm, a logLik object.
If the log-likelihood was not computed for object, produces an error
unless eval.loglik=TRUE
Hunter, D. R. and Handcock, M. S. (2006) Inference in curved exponential family models for networks, Journal of Computational and Graphical Statistics.