stergm fit.## S3 method for class 'stergm':
mcmc.diagnostics(object,
center=TRUE,
curved=TRUE,
vars.per.page=3,
\dots)stergm.latticeExtra package is not installed.mcmc.diagnostics.ergm returns
some degeneracy information, if it is included in the original
object. The function is mainly used for its side effect, which is
to produce plots and summary output based on those plots.object contains the matrix of
statistics from the MCMC run as component $sample.
This matrix is actually an object of class mcmc and
can be used directly in the coda package to assess MCMC
convergence. Hence all MCMC diagnostic methods available
in coda are available directly. See the examples and
More information can be found by looking at the documentation of
stergm.
Raftery, A.E. and Lewis, S.M. (1995). The number of iterations, convergence diagnostics and generic Metropolis algorithms. In Practical Markov Chain Monte Carlo (W.R. Gilks, D.J. Spiegelhalter and S. Richardson, eds.). London, U.K.: Chapman and Hall.
This function is based on the coda package
It is based on the the
R function raftery.diag in coda. raftery.diag,
in turn, is based on the FORTRAN program gibbsit written by
Steven Lewis which is available from the Statlib archive.
ergm, stergm,network package,
coda package,
summary.ergm