Learn R Programming

tergm (version 3.4.1)

print.stergm: Separable Temporal Exponential Random Graph Models

Description

print.stergm and summary.stergm are the method used to print and summarize objects created by the stergm function.

Usage

# S3 method for stergm
print(x, digits = max(3, getOption("digits") - 3), …)
# S3 method for stergm
summary(object, …)

Arguments

x, object

A stergm object. See documentation for stergm.

digits

Significant digits for coefficients

Additional arguments, to be passed to lower-level functions in the future.

Value

The value returned is the stergm object itself.

Details

Automatically called when an object of class stergm is printed.

See Also

network, stergm