Rdocumentation
powered by
Learn R Programming
tergm (version 3.3.1)
stergm-internal: Internal tergm Objects
Description
Internal tergm functions.
Arguments
Details
Most of these are not to be called by the user (or in some cases are just waiting for proper documentation to be written :).
See Also
stergm, statnet-package