stergm.getMCMCsample is a low-level internal function not intended to be called directly by end users. It collects a sample of networks and
returns the formation and dissolution statistics of each sample, along with
a toggle matrix of the changes needed from the original network to each
in the sample. stergm.getMCMCsample.slave is an even lower-level
function that actually calls the C code.
stergm.getMCMCsample(nw, model.form, model.diss, model.mon,
MHproposal.form, MHproposal.diss, eta.form,
eta.diss, control, verbose)stergm.getMCMCsample.slave(Clist.form, Clist.diss, Clist.mon,
MHproposal.form, MHproposal.diss, eta.form,
eta.diss, control, verbose)
a network object
formation, dissolution, and
monitoring model, as returned by ergm.getmodel
formation, dissolution, and
monitoring "Clist", as returned by ergm.Cprepare
a list of parameters needed for MHproposals of the formations and dissolutions
vectors of natural parameters.
list of control paramters, probably from control.stergm
logical; whether this and other functions should be verbose
returns the MCMC sample as a list containing:
statsmatrix.form: the matrix of sampled statistics for 'model.form' RELATIVE TO INITIAL NETWORK
statsmatrix.diss: the matrix of sampled statistics for 'model.form' RELATIVE TO INITIAL NETWORK
statsmatrix.mon: the matrix of sampled statistics for 'model.mon' RELATIVE TO INITIAL NETWORK
newnetwork : the final network from the sampling process
changed : a toggle matrix, where the first column is the timestamp of the toggle and the 2nd and 3rd columns are the head & tail of the toggle; this is only returned if 'control'$changes is not NULL
maxchanges : the "MCMC Dyn workspace"; see 'maxchanges' in the input param list
This function is normally called inside simulate.stergm to prepare inputs for the C sampling code and return its results