tergm is a collection of extensions to
the ergm package to fit, diagnose, and
simulate models for dynamic networks --- networks that evolve over
time --- based on exponential-family random graph models (ERGMs). For
a list of functions type help(package='tergm') When publishing results obtained using this package, please cite the
original authors as described in citation(package="tergm").
All programs derived from this package must cite it.
ergm package implements a suite of tools
for modeling single networks using ERGMs.More recently, there has been a number of extensions of ERGMs to model evolution of networks, including the temporal ERGM (TERGM) of Hanneke et al. (2010) and the separable termporal ERGM (STERGM) of Krivitsky and Handcock (2013). The latter model allows familiar ERGM terms and statistics to be reused in a dynamic context, interpreted in terms of formation and dissolution of ties. Krivitsky (2012) suggested a method for fitting dyanmic models when only a cross-sectional network is available, provided some temporal information for it is available as well.
This package aims to implement these and other ERGM-based models for
network evoluation. At this time, it implements, via the
stergm function, the STERGMs, both a conditional MLE
(CMLE) fitting to a series of networks and an Equilibrium Generalized
Method of Moments Estimation (EGMME) for fitting to a single network
with temporal information. For further development, see the referenced
papers.
For detailed information on how to download and install the software,
go to the Statnet project website:
doi:10.1214/09-EJS548