tergm uses a Metropolis-Hastings (MH) algorithm provided by ergm to control the behavior of the Markov Chain Monte Carlo (MCMC) for sampling networks. The MCMC chain is intended to step around the sample space of possible networks, selecting a network at regular intervals to evaluate the statistics in the model. For each MCMC step, \(n\) (\(n=1\) in the simple case) toggles are proposed to change the dyad(s) to the opposite value. The probability of accepting the proposed change is determined by the MH acceptance ratio. The role of the different MH methods implemented in tergm is to vary how the sets of dyads are selected for toggle proposals. This is used in some cases to improve the performance (speed and mixing) of the algorithm, and in other cases to constrain the sample space.
tergm packageTODO: EXPLAIN TERGM PROPOSAL TYPES HERE
InitMHP.dissolution
InitMHP.dissolutionTNT
InitMHP.dissolutionMLE
InitMHP.dissolutionNonObservedMLE
InitMHP.formation
InitMHP.formationMLE
InitMHP.formationMLETNT
InitMHP.formationNonObservedMLE
InitMHP.formationTNT
InitMHP.dissolutionMLEblockdiag
InitMHP.dissolutionNonObservedMLEblockdiag
InitMHP.formationMLEblockdiag
InitMHP.formationMLEblockdiagTNT
InitMHP.formationNonObservedMLEblockdiag
InitMHP.dissolutionMLETNT
InitMHP.dissolutionMLEblockdiagTNT
InitMHP.dissolutionNonObservedMLETNT
InitMHP.dissolutionNonObservedMLEblockdiagTNT
InitMHP.formationNonObservedMLETNT
InitMHP.formationNonObservedMLEblockdiagTNT
Goodreau SM, Handcock MS, Hunter DR, Butts CT, Morris M (2008a). A statnet Tutorial. Journal of Statistical Software, 24(8). http://www.jstatsoft.org/v24/i08/.
Hunter, D. R. and Handcock, M. S. (2006) Inference in curved exponential family models for networks, Journal of Computational and Graphical Statistics.
Hunter DR, Handcock MS, Butts CT, Goodreau SM, Morris M (2008b). ergm: A Package to Fit, Simulate and Diagnose Exponential-Family Models for Networks. Journal of Statistical Software, 24(3). http://www.jstatsoft.org/v24/i03/.
Krivitsky PN (2012). Exponential-Family Random Graph Models for Valued
Networks. Electronic Journal of Statistics, 2012, 6,
1100-1128. doi:10.1214/12-EJS696
Morris M, Handcock MS, Hunter DR (2008). Specification of Exponential-Family Random Graph Models: Terms and Computational Aspects. Journal of Statistical Software, 24(4). http://www.jstatsoft.org/v24/i04/.
tergm package, ergm, ergm-constraints, and ergm's MHproposal help page