imputers
A character vector giving one or more methods to impute missing
dyads. Currenly implemented methods are as follows:
[object Object],[object Object],[object Object],[object Object],[object Object]
If length(imputers)>1 the specifie
nwl.prepend
An optional list of networks to treat as preceding those in
nwl. They will not be imputed or returned, but they can be
useful for imputing dyads in the first network in nwl, when
using "previous" imputer.
nwl.append
An optional list of networks to treat as following those in
nwl. They will not be imputed or returned, but they can be
useful for imputing dyads in the last network in nwl, when
using "next" imputer.