print.stergm and summary.stergm are the method
used to print and summarize objects created by the stergm
function.
# S3 method for stergm
print(x, digits = max(3, getOption("digits") - 3), …)
# S3 method for stergm
summary(object, …)Significant digits for coefficients
Additional arguments, to be passed to lower-level functions in the future.
The value returned is the stergm object itself.
Automatically called when an object of class stergm is printed.