Learn R Programming

tergm (version 3.3.1)

stergm.getMCMCsample: Collects a sample of networks and returns the formation and dissolution statistics of each sample

Description

stergm.getMCMCsample is a low-level internal function not intended to be called directly by end users. It collects a sample of networks and returns the formation and dissolution statistics of each sample, along with a toggle matrix of the changes needed from the original network to each in the sample

Usage

stergm.getMCMCsample(nw, model.form, model.diss, model.mon, 
                    MHproposal.form, MHproposal.diss, 
                    eta.form, eta.diss, control, verbose)

Arguments

nw
a network object
model.form
a formation model, as returned by ergm.getmodel
model.diss
a dissolution model, as returned by ergm.getmodel
model.mon
MHproposal.form
a list of parameters needed for MHproposals of the formations
MHproposal.diss
a list of parameters needed for MHproposals of the dissolutions
eta.form
eta.diss
control
list of control paramters, probably from control.stergm
verbose
logical; whether this and other functions should be verbose

Value

  • returns the MCMC sample as a list containing:
    • statsmatrix.form: the matrix of sampled statistics for 'model.form' RELATIVE TO INITIAL NETWORK
  • statsmatrix.diss: the matrix of sampled statistics for 'model.form' RELATIVE TO INITIAL NETWORK
  • statsmatrix.mon: the matrix of sampled statistics for 'model.mon' RELATIVE TO INITIAL NETWORK
  • newnetwork : the final network from the sampling process
  • changed : a toggle matrix, where the first column is the timestamp of the toggle and the 2nd and 3rd columns are the head & tail of the toggle; this is only returned if 'control'$changes is not NULL
  • maxchanges : the "MCMC Dyn workspace"; see 'maxchanges' in the input param list

Details

This function is normally called inside simulate.stergm to prepare inputs for the C sampling code and return its results

See Also

simulate.stergm