stergm.getMCMCsample is a low-level internal function not intended to be called directly by end users. It collects a sample of networks and
returns the formation and dissolution statistics of each sample, along with
a toggle matrix of the changes needed from the original network to each
in the samplestergm.getMCMCsample(nw, model.form, model.diss, model.mon,
MHproposal.form, MHproposal.diss,
eta.form, eta.diss, control, verbose)network objectergm.getmodelergm.getmodelcontrol.stergmsimulate.stergm to prepare inputs for the C sampling code and return its resultssimulate.stergm