tergm uses a Metropolis-Hastings (MH) algorithm provided by ergm to control the behavior of the Markov Chain Monte Carlo (MCMC) for sampling networks. The MCMC chain is intended to step around the sample space of possible networks, selecting a network at regular intervals to evaluate the statistics in the model. For each MCMC step, $n$ ($n=1$ in the simple case) toggles are proposed to change the dyad(s) to the opposite value. The probability of accepting the proposed change is determined by the MH acceptance ratio. The role of the different MH methods implemented in tergm is to vary how the sets of dyads are selected for toggle proposals. This is used in some cases to improve the performance (speed and mixing) of the algorithm, and in other cases to constrain the sample space.tergm packageTODO: EXPLAIN TERGM PROPOSAL TYPES HERE
doi:10.1214/12-EJS696}
Morris M, Handcock MS, Hunter DR (2008).
Specification of Exponential-Family Random Graph Models:
Terms and Computational Aspects.
Journal of Statistical Software, 24(4).
tergm package, ergm, ergm-constraints, and ergm's MHproposal help page